@@ -56,13 +56,13 @@ do_view_action() {
         esac
         ;;
     pod)
-        pod2man "${MC_EXT_FILENAME}" | nroff -c -Tlatin1 -mandoc
+        pod2man "${MC_EXT_FILENAME}" | nroff  -man
         ;;
     nroff.me)
-        nroff -c -Tlatin1 -me "${MC_EXT_FILENAME}"
+        nroff  -me "${MC_EXT_FILENAME}"
         ;;
     nroff.ms)
-        nroff -c -Tlatin1 -ms "${MC_EXT_FILENAME}"
+        nroff  -ms "${MC_EXT_FILENAME}"
         ;;
     man.gz|man.bz|man.bz2|man.lz|man.lz4|man.lzma|man.xz)
         case "${MC_EXT_FILENAME}" in
@@ -98,18 +98,18 @@ do_open_action() {
             ;;
         *)
             { zsoelim "${MC_EXT_FILENAME}" 2>/dev/null || cat "${MC_EXT_FILENAME}"; } | \
-                nroff -c -Tlatin1 -mandoc
+                nroff  -man
             ;;
         esac | ${pager}
         ;;
     pod)
-        pod2man "${MC_EXT_FILENAME}" | nroff -c -Tlatin1 -mandoc | ${pager}
+        pod2man "${MC_EXT_FILENAME}" | nroff  -man | ${pager}
         ;;
     nroff.me)
-        nroff -c -Tlatin1 -me "${MC_EXT_FILENAME}" | ${pager}
+        nroff  -me "${MC_EXT_FILENAME}" | ${pager}
         ;;
     nroff.ms)
-        nroff -c -Tlatin1 -ms "${MC_EXT_FILENAME}" | ${pager}
+        nroff  -ms "${MC_EXT_FILENAME}" | ${pager}
         ;;
     man.gz|man.bz|man.bz2|man.lz|man.lz4|man.lzma|man.xz)
         case "${MC_EXT_FILENAME}" in
@@ -117,7 +117,7 @@ do_open_action() {
             ${unpacker} "${MC_EXT_FILENAME}"
             ;;
         *)
-            ${unpacker} "${MC_EXT_FILENAME}" | nroff -c -Tlatin1 -mandoc
+            ${unpacker} "${MC_EXT_FILENAME}" | nroff  -man
             ;;
         esac | ${pager}
         ;;
